import os
import subprocess
import sys
import argparse
import pylast
import keyring
from dateutil.parser import parse


def get_keys():
    username = os.getenv("USER", "")
    keys = keyring.get_password('lastfm_keys', username)
    if keys is None:
        url = "http://www.last.fm/api/account"
        keys = raw_input(
            "Enter your keys (<API_KEY>:<SECRET_KEY>) from %s>  " % url)
        keyring.set_password('lastfm_keys', username, keys)
    return keys.split(":")


def resolvePackageReference(reference):
    """stolen from collective.transmogrifier.utils
    """
    package, filename = reference.strip().split(':', 1)
    package = __import__(package, {}, {}, ('*',))
    return os.path.join(os.path.dirname(package.__file__), filename)


def main():
    parser = argparse.ArgumentParser(description="What's playing on last.fm?")
    parser.add_argument(
        'username',
        metavar='username',
        type=str,
        nargs=1,
        help='The username to look up')
    parser.add_argument(
        "-s", "--update-status",
        action="store_true",
        default=False,
        help="pass this option to update your iChat status",
    )
    args = parser.parse_args()
    username = args.username[0]
    api_key, secret_key = get_keys()
    network = pylast.get_lastfm_network(api_key, secret_key)
    user = network.get_user(username)
    try:
        now_playing = user.get_now_playing()
    except (pylast.WSError), e:
        print "ERROR: %s" % e.details
        sys.exit(1)
    if now_playing is None:
        print "%s is not currently playing anything" % username
        sys.exit(1)
    artist = now_playing.artist
    album = now_playing.get_album()
    song = now_playing.get_name()
    if album is not None:
        release_date = album.get_release_date()
        date = parse(release_date)
        year = " (%s)" % date.year
        # get the album name by stripping the artist out of it
        album = str(album).strip("%s - " % str(artist))
        # format it for the print out
        album = " - %s" % album
    else:
        year = ""
        album = ""
    # print it all out
    now_playing = "%(song)s%(album)s%(year)s - %(artist)s" % locals()
    print now_playing
    if args.update_status:
        now_playing = now_playing.replace('"', "'")
        script_name = "ichat_status.applescript"
        script_path = resolvePackageReference(
            "sixfeetup.nowplaying:%s" % script_name)
        subprocess.call(
            'osascript %s "%s"' % (script_path, now_playing),
            shell=True)


if __name__ == '__main__':
    main()
